@@ -16,7 +16,7 @@ use strict;
 use warnings;
 
 use vars qw($VERSION $STRING_VERSION);
-$VERSION        = '4.001_052';
+$VERSION        = '4.001_053';
 $STRING_VERSION = $VERSION;
 ## no critic(BuiltinFunctions::ProhibitStringyEval)
 $VERSION = eval $VERSION;
@@ -113,7 +113,7 @@ sub ast_to_hash {
     };
     Marpa::R3::exception($EVAL_ERROR) if not $eval_ok;
 
-    # Add the augment rule
+    # Add the G1 augment rule
     {
         my $start_lhs = $hashed_ast->{'start_lhs'}
           // $hashed_ast->{'first_lhs'};
@@ -178,6 +178,31 @@ sub ast_to_hash {
         push @{ $hashed_ast->{rules}->{l0} }, $wrl;
     }
 
+    # Add the L0 augment rule
+    if (1) {
+        # Target symbol assumed to exist already
+        my $target_lhs = '[:target:]';
+        Marpa::R3::exception('No rules in SLIF L0 grammar')
+          if not defined $target_lhs;
+        my $augment_lhs = '[:lex_start:]';
+        my $symbol_data = {
+            dsl_form    => $augment_lhs,
+            name_source => 'internal',
+        };
+        $hashed_ast->xsy_create( $augment_lhs, $symbol_data );
+        $hashed_ast->symbol_names_set( $augment_lhs, 'l0', { xsy => $augment_lhs } );
+
+        my $rule_data = {
+            start  => 0,
+            length => 0,
+            lhs    => $augment_lhs,
+            rhs    => [$target_lhs],
+        };
+        $hashed_ast->symbol_assign_ordinary($target_lhs, 'l0');
+        my $wrl = $hashed_ast->xpr_create( $rule_data, 'l0' );
+        push @{ $hashed_ast->{rules}->{l0} }, $wrl;
+    }
+
     my %l0_lhs = ();
     my %l0_rhs = ();
     RULE: for my $rule (values %{$hashed_ast->{xpr}->{l0}}) {
@@ -203,6 +228,7 @@ sub ast_to_hash {
     $lexeme{$_} = 'a lexeme in G1' for grep { not $g1_lhs{$_} } keys %g1_rhs;
     $lexeme{$_} = 'a declared lexeme' for keys %{$declarations};
   LEXEME: for my $lexeme ( sort keys %lexeme ) {
+        next LEXEME if $lexeme eq '[:lex_start:]';
         $declarations->{$lexeme} //= {};
         if ( $lexeme ne '[:discard:]' ) {
             if ( not $l0_lhs{$lexeme} ) {
@@ -226,7 +252,7 @@ sub ast_to_hash {
                     "    A lexeme cannot be the LHS of any G1 rule\n"
                 );
             }
-            if ( not $g1_rhs{$lexeme} ) {
+            if ( not $g1_rhs{$lexeme} and $lexeme ne '[:lex_start:]') {
                 my $type = $lexeme{$lexeme};
                 Marpa::R3::exception(
 "<$lexeme> is $type, but is not on the RHS of any G1 rule\n",
@@ -236,22 +262,22 @@ sub ast_to_hash {
         }
 
         {
-            my $lex_start_lhs = '[:lex_start:]';
+            my $target_lhs = '[:target:]';
             my $symbol_data = {
-                dsl_form    => $lex_start_lhs,
+                dsl_form    => $target_lhs,
                 name_source => 'internal',
             };
-            $hashed_ast->xsy_assign( $lex_start_lhs, $symbol_data );
-            $hashed_ast->symbol_names_set( $lex_start_lhs, 'l0',
-                { xsy => $lex_start_lhs } );
+            $hashed_ast->xsy_assign( $target_lhs, $symbol_data );
+            $hashed_ast->symbol_names_set( $target_lhs, 'l0',
+                { xsy => $target_lhs } );
 
             my $rule_data = {
                 start  => 0,
                 length => 0,
-                lhs    => $lex_start_lhs,
+                lhs    => $target_lhs,
                 rhs    => [$lexeme],
             };
-            $hashed_ast->symbol_assign_ordinary( $lex_start_lhs, 'l0' );
+            $hashed_ast->symbol_assign_ordinary( $target_lhs, 'l0' );
             my $wrl = $hashed_ast->xpr_create( $rule_data, 'l0' );
             push @{ $hashed_ast->{rules}->{l0} }, $wrl;
         }
@@ -267,6 +293,8 @@ sub ast_to_hash {
     }
     $hashed_ast->{character_classes} = \%stripped_character_classes;
 
+    # say STDERR Data::Dumper::Dumper($hashed_ast);
+
     return $hashed_ast;
 } ## end sub ast_to_hash
 
