@@ -16,7 +16,7 @@ use strict;
 use warnings;
 
 use vars qw($VERSION $STRING_VERSION);
-$VERSION        = '4.001_052';
+$VERSION        = '4.001_053';
 $STRING_VERSION = $VERSION;
 ## no critic(BuiltinFunctions::ProhibitStringyEval)
 $VERSION = eval $VERSION;
@@ -262,6 +262,26 @@ END_OF_LUA
         delete $flat_args->{'ranking_method'};
     }
 
+    if ( exists $flat_args->{'debug_level'} ) {
+
+        my $value = $flat_args->{'debug_level'} // 'undefined';
+
+    $slg->call_by_tag( ( '@' . __FILE__ . ':' . __LINE__ ),
+        <<'END_OF_LUA', 'i', $value);
+    local slg, raw_value = ...
+    local value = math.tointeger(raw_value)
+    if not value then
+        _M.userX(
+            'debug_level value is %s -- it should be an integer',
+            inspect(value)
+        )
+    end
+    slg.debug_level = value
+END_OF_LUA
+
+        delete $flat_args->{'debug_level'};
+    }
+
     return $dsl;
 
 }
@@ -838,12 +858,7 @@ sub Marpa::R3::Grammar::nsys_show {
         <<'END_OF_LUA', '' );
     local grammar = ...
     local g1g = grammar.g1
-    local nsy_count = g1g:_nsy_count()
-    local pieces = {}
-    for nsy_id = 0, nsy_count - 1 do
-        pieces[#pieces+1] = g1g:nsy_show(nsy_id)
-    end
-    return table.concat(pieces)
+    return g1g:nsys_show()
 END_OF_LUA
     return $result;
 }
