@@ -16,7 +16,7 @@ use strict;
 use warnings;
 
 use vars qw($VERSION $STRING_VERSION);
-$VERSION        = '4.001_052';
+$VERSION        = '4.001_053';
 $STRING_VERSION = $VERSION;
 ## no critic(BuiltinFunctions::ProhibitStringyEval)
 $VERSION = eval $VERSION;
@@ -117,7 +117,7 @@ sub gen_app_event_handler {
           $slr->[Marpa::R3::Internal_R::CURRENT_EVENT];
         if ($current_event) {
             Marpa::R3::exception(
-                qq{Attempt to throw call one event handler inside another\n},
+                qq{Attempt to call one event handler inside another\n},
                 qq{  This is not allowed\n},
                 qq{  The currently active handler is for a "$current_event" event\n},
                 qq{  The attempted handler call is for a "$event_name" event\n}
@@ -276,6 +276,7 @@ sub Marpa::R3::Recognizer::new {
                     say {$trace_file_handle} $msg;
                     return 'ok';
                 },
+                codepoint => gen_codepoint_event_handler($slr),
                 event => gen_app_event_handler($slr),
             }
         },
@@ -573,7 +574,7 @@ sub Marpa::R3::Recognizer::g1_pos {
     ('@' . __FILE__ . ':' . __LINE__),
     <<'END_OF_LUA', '');
     local recce = ...
-    local latest_earley_set = recce.g1:latest_earley_set()
+    local latest_earley_set = recce:latest_earley_set()
     return latest_earley_set
 END_OF_LUA
     return $latest_earley_set;
@@ -585,39 +586,63 @@ sub Marpa::R3::Recognizer::current_earleme {
     ('@' . __FILE__ . ':' . __LINE__),
     <<'END_OF_LUA', '');
     local recce = ...
-    local current_earleme = recce.g1:current_earleme()
+    local current_earleme = recce:current_earleme()
     return current_earleme
 END_OF_LUA
     return $current_earleme;
 }
 
-# Not documented, I think
+sub Marpa::R3::Recognizer::closest_earleme {
+    my ($slr) = @_;
+    my ($closest_earleme) = $slr->call_by_tag(
+    ('@' . __FILE__ . ':' . __LINE__),
+        <<'END_OF_LUA', '');
+    local recce = ...
+    local closest_earleme = recce:closest_earleme()
+    return closest_earleme
+END_OF_LUA
+    return $closest_earleme;
+}
+
 sub Marpa::R3::Recognizer::furthest_earleme {
     my ($slr) = @_;
     my ($furthest_earleme) = $slr->call_by_tag(
     ('@' . __FILE__ . ':' . __LINE__),
         <<'END_OF_LUA', '');
     local recce = ...
-    local furthest_earleme = recce.g1:furthest_earleme()
+    local furthest_earleme = recce:furthest_earleme()
     return furthest_earleme
 END_OF_LUA
     return $furthest_earleme;
 }
 
+sub Marpa::R3::Recognizer::latest_earleme {
+    my ($slr) = @_;
+    my ($latest_earleme) = $slr->call_by_tag(
+    ('@' . __FILE__ . ':' . __LINE__),
+        <<'END_OF_LUA', '');
+    local recce = ...
+    local latest_earleme = recce:latest_earleme()
+    return latest_earleme
+END_OF_LUA
+    return $latest_earleme;
+}
+
 sub Marpa::R3::Recognizer::earleme {
     my ( $slr, $earley_set_id ) = @_;
     my ($earleme) = $slr->call_by_tag(
     ('@' . __FILE__ . ':' . __LINE__),
         <<'END_OF_LUA', 'i', $earley_set_id);
     local recce, earley_set_id = ...
-    local earleme = recce.g1:earleme(earley_set_id)
+    local earleme = recce:earleme(earley_set_id)
     return earleme
 END_OF_LUA
     return $earleme;
 }
 
 sub Marpa::R3::Recognizer::lexeme_alternative_literal {
-    my ( $slr, $symbol_name ) = @_;
+    my ( $slr, $symbol_name, $length ) = @_;
+    $length //= 1;
 
     Marpa::R3::exception(
         "slr->alternative_literal(): symbol name is undefined\n",
@@ -625,16 +650,17 @@ sub Marpa::R3::Recognizer::lexeme_alternative_literal {
     ) if not defined $symbol_name;
 
     my ($ok) = $slr->call_by_tag( ( '@' . __FILE__ . ':' . __LINE__ ),
-        <<'END_OF_LUA', 's', $symbol_name);
-        local slr, symbol_name = ...
-        return slr:lexeme_alternative_literal(symbol_name)
+        <<'END_OF_LUA', 'si', $symbol_name, $length);
+        local slr, symbol_name, length = ...
+        return slr:lexeme_alternative_literal(symbol_name, length)
 END_OF_LUA
     return 1 if $ok;
     return;
 }
 
 sub Marpa::R3::Recognizer::lexeme_alternative {
-    my ( $slr, $symbol_name, $value ) = @_;
+    my ( $slr, $symbol_name, $value, $length ) = @_;
+    $length //= 1;
 
     if ( Scalar::Util::tainted( $value ) ) {
         Marpa::R3::exception(
@@ -651,15 +677,15 @@ sub Marpa::R3::Recognizer::lexeme_alternative {
     my $ok;
     if (defined $value) {
     ($ok) = $slr->call_by_tag( ( '@' . __FILE__ . ':' . __LINE__ ),
-        <<'END_OF_LUA', 'sS', $symbol_name, $value );
-        local slr, symbol_name, token_sv = ...
-        return slr:lexeme_alternative(symbol_name, token_sv)
+        <<'END_OF_LUA', 'sSi', $symbol_name, $value, $length );
+        local slr, symbol_name, token_sv, length = ...
+        return slr:lexeme_alternative(symbol_name, token_sv, length)
 END_OF_LUA
     } else {
     ($ok) = $slr->call_by_tag( ( '@' . __FILE__ . ':' . __LINE__ ),
-        <<'END_OF_LUA', 's', $symbol_name );
-        local slr, symbol_name = ...
-        return slr:lexeme_alternative_undef(symbol_name )
+        <<'END_OF_LUA', 'si', $symbol_name, $length );
+        local slr, symbol_name, length = ...
+        return slr:lexeme_alternative_undef(symbol_name, length )
 END_OF_LUA
     }
 
@@ -694,6 +720,7 @@ sub Marpa::R3::Recognizer::lexeme_complete {
                     say {$trace_file_handle} $msg;
                     return 'ok';
                },
+               codepoint => gen_codepoint_event_handler($slr),
                event => gen_app_event_handler($slr),
            }
         },
@@ -1238,7 +1265,7 @@ sub Marpa::R3::Recognizer::earley_set_size {
         <<'END_OF_LUA', 'i', ($set_id // -1));
     local recce, set_id = ...
     local g1r = recce.g1
-    if set_id < 0 then set_id = g1r:lastest_earley_set() end
+    if set_id < 0 then set_id = g1r:latest_earley_set() end
     return g1r:_earley_set_size(set_id)
 END_OF_LUA
     return $size;
